@@ -70,9 +70,9 @@ group1.name = "GroupA", group2.name = "GroupB", description=TRUE)
 	time<-factor(time)
 	FAC.1<-factor(factor1)
 	FAC.2<-factor(factor2)
-	facs.1 <- sort(levels(FAC.1))
-	facs.2 <- sort(levels(FAC.2))
-	tlevel <- sort(levels(time))
+	facs.1 <- levels(FAC.1)
+	facs.2 <- levels(FAC.2)
+	tlevel <- levels(time)
 	varL <- 1-is.na(var)
 
 	T<-nlevels(time)
